@@ -5,4 +5,4 @@ from protonfixes import util
 
 def main() -> None:
     util.disable_protonmediaconverter()
-    util.winedll_override('wmvdecod', util.OverrideOrder.DISABLED)
+    util.set_environment('PROTON_MEDIA_USE_GST', '1')
