@@ -4,5 +4,5 @@ from protonfixes import util
 
 
 def main() -> None:
-    """Game ships with outdated and not working uPlay launcher."""
+    """Game ships with outdated UPlay launcher, which impedes normal initialization"""
     util.protontricks('ubisoftconnect')
